@@ -102,6 +102,16 @@ Parses with (requires) L<YAML>.
 
 =back
 
+=head1 SEE ALSO
+
+=over 4
+
+=item * L<Spreadsheet::HTML>
+
+The interface for this functionality.
+
+=back
+
 =cut
 
 1;
@@ -169,7 +179,7 @@ sub _parse {
     return [[ "cannot load $file" ],[ 'please install HTML::TableExtract' ]] if $NOT_AVAILABLE;
 
     my @data;
-    my $extract = HTML::TableExtract->new( keep_headers => 1 );
+    my $extract = HTML::TableExtract->new( keep_headers => 1, decode => 0 );
     $extract->parse_file( $file );
     my $table = ($extract->tables)[ $args->{worksheet} - 1 ];
     return [ $table ? $table->rows : [undef] ];
