@@ -356,12 +356,12 @@ These methods are not meant to be called from this package.
 Instead, use the Spreadsheet::HTML interface:
 
   use Spreadsheet::HTML;
-  my $generator = Spreadsheet::HTML->new( data => [[1],[2]] );
-  print $generator->layout();
+  my $generator = Spreadsheet::HTML->new( data => \@data );
+  print $generator->layout;
 
   # or
   use Spreadsheet::HTML qw( layout );
-  print layout( data => [[1],[2]] );
+  print layout( data => \@data );
 
 =head1 METHODS
 
@@ -379,11 +379,10 @@ no HTML entity encoding in table cells.
 
 Preset for tables with checkerboard colors.
 
-  checkerboard( colors => [qw(yellow orange)], extra => 'blue' )
+  checkerboard( colors => [qw(yellow orange blue)] )
 
-Attempts to form diagonal patterns by adding an extra color
-if need be. C<colors> default to red and green and C<extra>
-defaults to white.
+Forms diagonal patterns by alternating the starting background
+colors for each row. C<colors> defaults to red and green.
 
 =item * C<banner( dir, text, emboss, on, off, fill, %params )>
 
@@ -471,6 +470,16 @@ Generate 9x9 HTML table sudoku boards.
 
 =back
 
+=head1 SEE ALSO
+
+=over 4
+
+=item * L<Spreadsheet::HTML>
+
+The interface for this functionality.
+
+=back
+
 =head1 AUTHOR
 
 Jeff Anderson, C<< <jeffa at cpan.org> >>
