@@ -189,7 +189,7 @@ Instead, use the Spreadsheet::HTML interface:
 
   use Spreadsheet::HTML;
   my $generator = Spreadsheet::HTML->new;
-  print $generator->calculator();
+  print $generator->calculator;
 
   # or
   use Spreadsheet::HTML qw( calculator );
@@ -215,8 +215,12 @@ via L<Javascript::Minifier> if it is installed.
 
 =item L<Spreadsheet::HTML>
 
+The interface for this functionality.
+
 =item L<Spreadsheet::HTML::Presets>
 
+More presets.
+
 =back
 
 =head1 AUTHOR
