@@ -89,12 +89,12 @@ These methods are not meant to be called from this package.
 Instead, use the Spreadsheet::HTML interface:
 
   use Spreadsheet::HTML;
-  my $generator = Spreadsheet::HTML->new( data => [[1],[2]] );
-  print $generator->handson( );
+  my $generator = Spreadsheet::HTML->new( data => \@data );
+  print $generator->handson;
 
   # or
   use Spreadsheet::HTML qw( handson );
-  print handson( data => [[1],[2]] );
+  print handson( data => \@data );
 
 =head1 METHODS
 
@@ -128,12 +128,14 @@ via L<Javascript::Minifier> if it is installed.
 
 =over 4
 
-=item L<http://www.handsontable.com/>
-
 =item L<Spreadsheet::HTML>
 
+The interface for this functionality.
+
 =item L<Spreadsheet::HTML::Presets>
 
+More presets.
+
 =back
 
 =head1 AUTHOR
