@@ -168,7 +168,7 @@ Instead, use the Spreadsheet::HTML interface:
 
   use Spreadsheet::HTML;
   my $generator = Spreadsheet::HTML->new;
-  print $generator->tictactoe();
+  print $generator->tictactoe;
 
   # or
   use Spreadsheet::HTML qw( tictactoe );
@@ -192,8 +192,12 @@ implement a computer opponent.
 
 =item L<Spreadsheet::HTML>
 
+The interface for this functionality.
+
 =item L<Spreadsheet::HTML::Presets>
 
+More presets.
+
 =back
 
 =head1 AUTHOR
